Module layering

Module layering 

Structs

LayerGroup
A group of packages that will be combined into a single OCI layer.

Enums

PackingStrategy
Strategy for grouping packages into OCI layers.

Functions

pack
Group packages into layer groups according to strategy.
placeholder_descriptor
Convert a ResolvedPackage into a LayerDescriptor placeholder. The actual digest and size are filled in by build::build_layer after the layer blob has been created.