Module oci

Module oci 

Functions

load_from_tarball
Load an OCI image from a tarball previously saved by save_oci_tarball.
push
Push an OciImage to a registry.
push_authenticated
Push an OciImage to a registry using an explicit token.
verify
Fetch an image manifest from a registry and verify its digest matches expected_digest.