push_authenticated

Function push_authenticated 

pub async fn push_authenticated(
    image: &OciImage,
    reference: &str,
    token: &str,
) -> Result<String>
Push an OciImage to a registry using an explicit token.

Use this from callers that already have a GHCR token from user auth, rather than relying on the GITHUB_TOKEN env var.