resolve

Function resolve 

pub async fn resolve(spec: &BuildSpec) -> Result<ResolvedSpec>
Resolve a BuildSpec to a fully pinned ResolvedSpec using the conda repodata from the declared channels.

Resolution strategy:

  1. Download repodata.json for each channel + subdir.
  2. BFS from the declared packages, resolving each transitive dependency.
  3. Return a deterministically sorted ResolvedSpec.