pub fn catalog_coverage(
packages: &[ResolvedPackage],
catalog: &LayerCatalog,
) -> (usize, usize)Expand description
Collect all conda packages included in a resolved spec’s layer list, grouped by whether they already appear in the catalog.
pub fn catalog_coverage(
packages: &[ResolvedPackage],
catalog: &LayerCatalog,
) -> (usize, usize)Collect all conda packages included in a resolved spec’s layer list, grouped by whether they already appear in the catalog.